@@ -75,6 +75,8 @@ class TonlibManager:
         self.raw_run_method = self.cache_manager.cached(expire=5)(self.raw_run_method)
         self.raw_estimate_fees = self.cache_manager.cached(expire=5)(self.raw_estimate_fees)
         self.getMasterchainInfo = self.cache_manager.cached(expire=1)(self.getMasterchainInfo)
+        self.getMasterchainBlockSignatures = self.cache_manager.cached(expire=5)(self.getMasterchainBlockSignatures)
+        self.getShardBlockProof = self.cache_manager.cached(expire=5)(self.getShardBlockProof)
         self.lookupBlock = self.cache_manager.cached(expire=600)(self.lookupBlock)
         self.getShards = self.cache_manager.cached(expire=600)(self.getShards)
         self.raw_getBlockTransactions = self.cache_manager.cached(expire=600)(self.raw_getBlockTransactions)
@@ -377,6 +379,12 @@ class TonlibManager:
     async def getMasterchainInfo(self):
         return await self.dispatch_request('get_masterchain_info')
 
+    async def getMasterchainBlockSignatures(self, seqno):
+        return await self.dispatch_request('get_masterchain_block_signatures', seqno)
+    
+    async def getShardBlockProof(self, workchain, shard, seqno, from_seqno):
+        return await self.dispatch_request('get_shard_block_proof', workchain, shard, seqno, from_seqno)
+
     async def getConsensusBlock(self):
         return {
             "consensus_block": self.consensus_block.seqno,
